HashDiversityInfo
=================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: HashDiversityInfo
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~HashDiversityInfo.uniques_per_representation
      ~HashDiversityInfo.uniques_total

   .. rubric:: Attributes Documentation

   .. autoattribute:: uniques_per_representation
   .. autoattribute:: uniques_total
